Module encoding

Module encoding 

Structs

UsizeActionMapper
A trivial action mapper for environments whose actions are plain usize.
VecEncoder
A trivial encoder for environments whose observations are already Vec<f32>.

Traits

DiscreteActionMapper
Maps between environment action types and integer indices.
ObservationEncoder
Converts environment observations into Burn tensors.