Module stats

Module stats 

Structs

EpisodeRecord
Stats recorded for a single completed episode.
EvalReport
Summary statistics from a single evaluation run.
Last
The most recent value, ignoring history.
Max
Maximum value seen since the last reset.
Mean
Running mean over all values seen since the last reset.
Min
Minimum value seen since the last reset.
RollingMean
Mean over the last window values (sliding window).
StatsTracker
Accumulates per-episode stats and reports summary aggregates.
Std
Population standard deviation over all values seen since the last reset.

Enums

StatSource
Predefined sources for StatsTracker::with.

Traits

Aggregator
Accumulates a stream of f64 values into a single summary statistic.