Structs
- Episode
Record - Stats recorded for a single completed episode.
- Eval
Report - Summary statistics from a single evaluation run.
- Last
- The most recent value, ignoring history.
- Max
- Maximum value seen since the last reset.
- Mean
- Running mean over all values seen since the last reset.
- Min
- Minimum value seen since the last reset.
- Rolling
Mean - Mean over the last
windowvalues (sliding window). - Stats
Tracker - Accumulates per-episode stats and reports summary aggregates.
- Std
- Population standard deviation over all values seen since the last reset.
Enums
- Stat
Source - Predefined sources for
StatsTracker::with.
Traits
- Aggregator
- Accumulates a stream of
f64values into a single summary statistic.